/*
    Copyright (C) 2002, Steve Lhomme <steve.lhomme @ free.fr>
    This file is part of mpa2wav.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Foobar; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
/**
    \file mpa2wav.cpp
    Convert MPEG I/II Layer 1/2/3 to RIFF/WAV/MPEG files
    \todo remove bad frames
    \todo the ID3v1 and v2 data could be put in a special WAV chunk
*/
#include <stdio.h>
#include <string>
#include <cassert>

#include "processus.h"

#if !defined(NO_NAMESPACE)
using namespace std;
using namespace M2W_NAMESPACE;
#endif

void usage()
{
    printf("This program converts MPEG I/II Layer 1/2/3 to RIFF-WAV-MPEG files\r\n\r\n");
    printf("Usage: mpa2wav [-a] <input-filename> [output-filename]\r\n");
//    printf("Usage: mpa2wav [-v] <input-filename> [output-filename]\r\n");
//    printf("\t-v verbose\n");
    printf("   -a also keep bad frames (not counted as valid data)\r\n");
    printf("   if no output file is specified the input filename is used with a .wav\r\n");
}

int main(int argc, char*argv[])
{
    bool bVerbose = true;
    bool bVerboseMore = true;
    bool bKeepAll = false;

    int FilenameIndex = 1;

    printf("mpa2wav v%s - (c) 2002 Steve Lhomme - GPL License\r\n", version);
    printf("              http://mukoli.free.fr/mpa2wav/\r\n");
    printf("Some code was borrowed from libMCF (c) 2002 - LGPL License\r\n");
    // check for the valid number of parameters
    if (argc < 2 || argc > 4)
    {
	usage();
	return -1;
    }

    if (argv[FilenameIndex][0] == '-')
    {
	FilenameIndex++;
	if (argv[FilenameIndex][1] == 'a')
	    bKeepAll = true;
    }

    string input_Filename = argv[FilenameIndex];
    FilenameIndex++;

    string output_Filename;
    if (FilenameIndex == argc-1)
	output_Filename = argv[FilenameIndex];
    else
	output_Filename = input_Filename + ".wav";

    return process(input_Filename, output_Filename, bKeepAll, bVerbose, bVerboseMore);
}
